@@ -202,7 +202,6 @@ typedef struct
 } autocomplete_t;
 
 extern patch_t          *consolefont[CONSOLEFONTSIZE];
-extern patch_t          *degree;
 extern patch_t          *lsquote;
 extern patch_t          *ldquote;
 extern patch_t          *unknownchar;
@@ -260,6 +259,7 @@ void C_Warning(const int minwarninglevel, const char *string, ...);
 void C_PlayerMessage(const char *string, ...);
 void C_PlayerObituary(const char *string, ...);
 void C_PlayerWarning(const char *string, ...);
+char *C_GetPlayerName(void);
 void C_ResetWrappedLines(void);
 void C_AddConsoleDivider(void);
 void C_ClearConsole(void);
