@@ -397,16 +397,16 @@ void G_BuildTiccmd(ticcmd_t *cmd)
         {
             if (!automapactive)
             {
-                cmd->lookdir = (int)(96 * ((float)controllerthumbRY / SHRT_MAX)
+                cmd->pitch = (int)(96 * ((float)controllerthumbRY / SHRT_MAX)
                     * controllerverticalsensitivity);
 
                 if (!joy_invertyaxis)
-                    cmd->lookdir = -cmd->lookdir;
+                    cmd->pitch = -cmd->pitch;
             }
         }
         else if (joy_thumbsticks == 1)
         {
-            cmd->lookdir = 0;
+            cmd->pitch = 0;
             forward = (int)(forwardmove[run] * (float)controllerthumbRY / SHRT_MAX);
         }
     }
@@ -631,7 +631,7 @@ void G_BuildTiccmd(ticcmd_t *cmd)
     if (mousey)
     {
         if (usefreelook && !automapactive)
-            cmd->lookdir = (m_invertyaxis ? -mousey : mousey);
+            cmd->pitch = (m_invertyaxis ? -mousey : mousey);
         else if (!m_novertical)
             forward += mousey / 2;
 
@@ -782,10 +782,11 @@ void G_DoLoadLevel(void)
     if (resetplayer && gamemap != 1)
     {
         if (M_StringCompare(playername, playername_default))
-            C_Warning(0, "You now have 100%% health, no armor, and only a pistol with 50 bullets.");
+            C_Warning(0, "You now have %i%% health, no armor, and only a pistol with %i bullets.",
+                initial_health, initial_bullets);
         else
-            C_Warning(0, "%s now has 100%% health, no armor, and only a pistol with 50 bullets.",
-                playername);
+            C_Warning(0, "%s now has %i%% health, no armor, and only a pistol with %i bullets.",
+                playername, initial_health, initial_bullets);
     }
 
     skycolumnoffset = 0;
@@ -896,6 +897,7 @@ bool G_Responder(const event_t *ev)
                 && (ev->data1 < KEY_F1 || ev->data1 > KEY_F12)
                 && ev->data1 != KEY_BACKSPACE
                 && ev->data1 != KEY_ALT
+                && ev->data1 != KEY_SHIFT
                 && !((ev->data1 == KEY_ENTER || ev->data1 == KEY_TAB) && altdown)
                 && ev->data1 != keyboardscreenshot
                 && ev->data1 != keyboardscreenshot2)
@@ -1813,7 +1815,7 @@ void G_LoadedGameMessage(void)
                 M_StringReplaceAll(temp2, ".", "", false);
                 M_StringReplaceAll(temp2, "!", "", false);
 
-                C_Warning(0, "The skill level is now " ITALICS("%s."), temp2);
+                C_Warning(0, "The skill level is now " ITALICS("%s") ".", temp2);
                 free(temp2);
             }
         }
