@@ -54,12 +54,6 @@
 #include <stdarg.h>
 #include <string.h>
 
-#include "c_console.h"
-#include "i_system.h"
-#include "m_config.h"
-#include "m_misc.h"
-#include "w_file.h"
-
 #if defined(__APPLE__)
 #import <Cocoa/Cocoa.h>
 
@@ -84,6 +78,12 @@
 #endif
 #endif
 
+#include "c_console.h"
+#include "i_system.h"
+#include "m_config.h"
+#include "m_misc.h"
+#include "w_file.h"
+
 const char *daynames[7] =
 {
     "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"
@@ -544,7 +544,7 @@ char *M_StringReplaceFirst(char *haystack, const char *needle, const char *repla
 }
 
 #if !defined(strrstr)
-char *strrstr(const char *haystack, const char *needle)
+static char *strrstr(const char *haystack, const char *needle)
 {
     char    *r = NULL;
 
@@ -799,36 +799,38 @@ char *commifystring(const char *str)
 {
     size_t  len = strlen(str);
 
-    if (!len)
-        return M_StringDuplicate("");
-
-    bool        negative = (str[0] == '-');
-    size_t      start = (negative ? 1 : 0);
-    const char  *dot = strchr(str + start, '.');
-    size_t      intlen = (dot ? (size_t)(dot - (str + start)) : len - start);
-    size_t      commas = (intlen > 3 ? (intlen - 1) / 3 : 0);
-    size_t      outlen = len + commas + 1;
-    char        *out = (char *)I_Malloc(outlen);
-    size_t      i = intlen;
-    size_t      j = intlen + commas;
-
-    out[j] = '\0';
-
-    while (i > 0)
+    if (len)
     {
-        out[--j] = str[start + --i];
+        bool        negative = (str[0] == '-');
+        size_t      start = (negative ? 1 : 0);
+        const char  *dot = strchr(str + start, '.');
+        size_t      intlen = (dot ? (size_t)(dot - (str + start)) : len - start);
+        size_t      commas = (intlen > 3 ? (intlen - 1) / 3 : 0);
+        size_t      outlen = len + commas + 1;
+        char        *out = (char *)I_Malloc(outlen);
+        size_t      i = intlen;
+        size_t      j = intlen + commas;
 
-        if (i > 0 && (intlen - i) % 3 == 0)
-            out[--j] = ',';
+        out[j] = '\0';
+
+        while (i > 0)
+        {
+            out[--j] = str[start + --i];
+
+            if (i > 0 && (intlen - i) % 3 == 0)
+                out[--j] = ',';
+        }
+
+        if (negative)
+            out[0] = '-';
+
+        if (dot)
+            strcat(out, dot);
+
+        return out;
     }
 
-    if (negative)
-        out[0] = '-';
-
-    if (dot)
-        strcat(out, dot);
-
-    return out;
+    return M_StringDuplicate("");
 }
 
 char *commifystat(uint64_t value)
