@@ -1243,7 +1243,7 @@ void A_CyberAttack(mobj_t *actor, player_t *player, pspdef_t *psp)
     mo = P_SpawnMissile(actor, target, MT_ROCKET);
 
     // [BH] give cyberdemon rockets smoke trails
-    if (r_rockettrails && !PUFFA0 && !norockettrails && !incompatiblepalette)
+    if (r_rockettrails && !PUFFA0 && !incompatiblepalette)
         mo->flags2 |= MF2_SMOKETRAIL;
 }
 
@@ -1312,7 +1312,7 @@ void A_Tracer(mobj_t *actor, player_t *player, pspdef_t *psp)
     // spawn a puff of smoke behind the homing rocket
     if (!doom4vanilla)
     {
-        if (r_rockettrails && !PUFFA0 && !norockettrails && !incompatiblepalette)
+        if (r_rockettrails && !PUFFA0 && !incompatiblepalette)
             actor->flags2 |= MF2_SMOKETRAIL;
         else
             P_SpawnPuff(actor->x, actor->y, actor->z, actor->angle);
