@@ -1601,8 +1601,7 @@ static void P_WriteObituary(mobj_t *target, mobj_t *inflicter, mobj_t *source, c
                     (*target->info->name1 && !M_StringStartsWith(target->info->name1, "Deh_Actor_") ? target->info->name1 : "monster"));
             }
 
-            C_PlayerMessage("%s telefragged %s.",
-                (M_StringCompare(playername, playername_default) ? "You" : playername), targetname);
+            C_PlayerMessage("%s telefragged %s.", C_GetPlayerName(), targetname);
         }
         else
         {
@@ -1933,18 +1932,16 @@ static void P_WriteObituary(mobj_t *target, mobj_t *inflicter, mobj_t *source, c
                 };
 
                 C_PlayerObituary("%s died in %s.",
-                    (M_StringCompare(playername, playername_default) ? "You" : playername),
-                    liquids[sector->terraintype - LIQUID][english]);
+                    C_GetPlayerName(), liquids[sector->terraintype - LIQUID][english]);
             }
             else
             {
                 const short floorpic = sector->floorpic;
 
                 if ((floorpic >= RROCK05 && floorpic <= RROCK08) || (floorpic >= SLIME09 && floorpic <= SLIME12))
-                    C_PlayerObituary("%s died on molten rock.",
-                        (M_StringCompare(playername, playername_default) ? "You" : playername));
+                    C_PlayerObituary("%s died on molten rock.", C_GetPlayerName());
                 else
-                    C_PlayerObituary("%s died.", (M_StringCompare(playername, playername_default) ? "You" : playername));
+                    C_PlayerObituary("%s died.", C_GetPlayerName());
             }
         }
     }
@@ -2381,7 +2378,7 @@ void P_DamageMobj(mobj_t *target, mobj_t *inflicter, mobj_t *source, int damage,
     }
     else if ((target->health -= damage) <= 0)   // do the damage
     {
-        if (!(flags & MF_FUZZ) && target->state != S_NULL && !target->state->dehacked
+        if (!(flags & MF_FUZZ) && target->state && !target->state->dehacked
             && (type == MT_BARREL || type == MT_SKULL || type == MT_PAIN))
             target->colfunc = tlredcolfunc;
 
