@@ -91,8 +91,14 @@ bool P_SetMobjState(mobj_t *mobj, statenum_t state)
             // Modified handling.
             // Call action functions when the state is set
             if (st->action)
+            {
                 st->action(mobj, NULL, NULL);
 
+                // [BH] If action function changed the state, don't continue with the original state sequence
+                if (mobj->state != st)
+                    break;
+            }
+
             seenstate[state] = 1 + st->nextstate;   // killough 4/9/98
             state = st->nextstate;
         }
@@ -1104,13 +1110,13 @@ static void P_SpawnPlayer(const mapthing_t *mthing)
     viewplayer->mo->floatbob = (M_BigRandom() & (ANIMATEDLIQUIDDIFFS - 1));
     viewplayer->momx = 0;
     viewplayer->momy = 0;
-    viewplayer->lookdir = 0;
+    viewplayer->pitch = 0;
     viewplayer->recoil = 0;
     viewplayer->jumptics = 0;
     viewplayer->bounce = 0;
     viewplayer->bouncemax = 0;
 
-    deadlookdir = -1;
+    deadpitch = -1;
 
     // setup gun psprite
     P_SetupPlayerSprites();
@@ -1206,14 +1212,14 @@ static void P_SpawnFriend(const mapthing_t *mthing)
         mobj->bloodsplats = CORPSEBLOODSPLATS;
 
         if (gamemap == 1)
-            C_Warning(0, "A friendly %s entered this map with %s!", mobjinfo[mobj->type].name1,
-                (M_StringCompare(playername, playername_default) ? "you" : playername));
+            C_Warning(0, "A friendly %s entered this map with %s!",
+                mobjinfo[mobj->type].name1, C_GetPlayerName());
         else if (*mobj->name)
             C_Warning(0, "%s followed %s into this map!",
-                mobj->name, (M_StringCompare(playername, playername_default) ? "you" : playername));
+                mobj->name, C_GetPlayerName());
         else
             C_Warning(0, "A friendly %s followed %s into this map!",
-                mobjinfo[mobj->type].name1, (M_StringCompare(playername, playername_default) ? "you" : playername));
+                mobjinfo[mobj->type].name1, C_GetPlayerName());
     }
 }
 
@@ -1500,7 +1506,7 @@ void P_SpawnPuff(const fixed_t x, const fixed_t y, const fixed_t z, const angle_
 //
 void P_SpawnSmokeTrail(const fixed_t x, const fixed_t y, const fixed_t z, const angle_t angle)
 {
-    mobj_t  *th = P_SpawnMobj(x, y, z + (M_BigSubRandom() << 10), MT_TRAIL);
+    mobj_t  *th = P_SpawnMobj(x, y, z + (M_BigSubRandom() << 10), MT_TRAIL2);
 
     th->momz = FRACUNIT / 2;
     th->angle = angle;
@@ -1640,7 +1646,7 @@ void P_SpawnBloodSplat(const fixed_t x, const fixed_t y, const int color, const
             && (!usemaxheight || sec->interpfloorheight <= maxheight)
             && (!checklineside || !P_CheckLineSide(target, x, y)))
         {
-            bloodsplat_t    *splat = malloc(sizeof(*splat));
+            bloodsplat_t    *splat = Z_Malloc(sizeof(*splat), PU_LEVEL, NULL);
 
             if (splat)
             {
@@ -1794,7 +1800,7 @@ mobj_t *P_SpawnPlayerMissile(mobj_t *source, mobjtype_t type)
     th->interpolate = -1;
 
     if (type == MT_ROCKET && r_rockettrails && !(th->flags & MF_BOUNCES)
-        && viewplayer->readyweapon == wp_missile && !chex && !hacx && !norockettrails && !incompatiblepalette)
+        && viewplayer->readyweapon == wp_missile && !chex && !hacx && !incompatiblepalette)
     {
         th->flags2 |= MF2_SMOKETRAIL;
         th->pursuecount = 0;
