@@ -62,6 +62,8 @@ int             fuzz2table[MAXSCREENAREA];
 static byte     *ylookup0[MAXHEIGHT];
 static byte     *ylookup1[MAXHEIGHT];
 
+static byte     flipindex[256];
+
 lighttable_t    *dc_colormap[2];
 lighttable_t    *dc_nextcolormap[2];
 lighttable_t    *dc_sectorcolormap;
@@ -194,7 +196,8 @@ void R_DrawLowResDitheredColumnWithBrightmap(void)
     int                 count = dc_yh - dc_yl + 1;
     byte                *dest = ylookup0[dc_yl] + dc_x;
     fixed_t             frac = dc_texturefrac;
-    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] }, { fullcolormap, fullcolormap } };
+    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] },
+                                            { fullcolormap,   fullcolormap       } };
     byte                dot;
 
     while (--count)
@@ -206,7 +209,7 @@ void R_DrawLowResDitheredColumnWithBrightmap(void)
     }
 
     dot = dc_source[frac >> FRACBITS];
-    *dest = dc_sectorcolormap[colormap[dc_brightmap[dot]][ditherlow(dc_x, dc_yl++, dc_z)][dot]];
+    *dest = dc_sectorcolormap[colormap[dc_brightmap[dot]][ditherlow(dc_x, dc_yl, dc_z)][dot]];
 }
 
 void R_DrawDitheredColumnWithBrightmap(void)
@@ -214,7 +217,8 @@ void R_DrawDitheredColumnWithBrightmap(void)
     int                 count = dc_yh - dc_yl + 1;
     byte                *dest = ylookup0[dc_yl] + dc_x;
     fixed_t             frac = dc_texturefrac;
-    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] }, { fullcolormap, fullcolormap } };
+    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] },
+                                            { fullcolormap,   fullcolormap       } };
     byte                dot;
 
     while (--count)
@@ -226,7 +230,7 @@ void R_DrawDitheredColumnWithBrightmap(void)
     }
 
     dot = dc_source[frac >> FRACBITS];
-    *dest = dc_sectorcolormap[colormap[dc_brightmap[dot]][dither(dc_x, dc_yl++, dc_z)][dot]];
+    *dest = dc_sectorcolormap[colormap[dc_brightmap[dot]][dither(dc_x, dc_yl, dc_z)][dot]];
 }
 
 void R_DrawCorrectedColumn(void)
@@ -599,7 +603,8 @@ void R_DrawLowResDitheredWallColumnWithBrightmap(void)
     int                 count = dc_yh - dc_yl + 1;
     byte                *dest = ylookup0[dc_yl] + dc_x;
     fixed_t             frac = dc_texturemid + (dc_yl - centery) * dc_iscale;
-    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] }, { fullcolormap, fullcolormap } };
+    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] },
+                                            { fullcolormap,   fullcolormap       } };
     fixed_t             heightmask = dc_texheight - 1;
     byte                dot;
 
@@ -646,7 +651,8 @@ void R_DrawDitheredWallColumnWithBrightmap(void)
     int                 count = dc_yh - dc_yl + 1;
     byte                *dest = ylookup0[dc_yl] + dc_x;
     fixed_t             frac = dc_texturemid + (dc_yl - centery) * dc_iscale;
-    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] }, { fullcolormap, fullcolormap } };
+    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] },
+                                            { fullcolormap,   fullcolormap       } };
     fixed_t             heightmask = dc_texheight - 1;
     byte                dot;
 
@@ -759,16 +765,15 @@ void R_DrawFlippedSkyColumn(void)
     byte                *dest = ylookup0[dc_yl] + dc_x;
     fixed_t             frac = dc_texturemid + (dc_yl - centery) * dc_iscale;
     const lighttable_t  *colormap = dc_colormap[0];
-    fixed_t             i;
 
     while (--count)
     {
-        *dest = dc_sectorcolormap[colormap[dc_source[(i = frac >> FRACBITS) < 128 ? i : 126 - (i & 127)]]];
+        *dest = dc_sectorcolormap[colormap[dc_source[flipindex[frac >> FRACBITS]]]];
         dest += SCREENWIDTH;
         frac += dc_iscale;
     }
 
-    *dest = dc_sectorcolormap[colormap[dc_source[(i = frac >> FRACBITS) < 128 ? i : 126 - (i & 127)]]];
+    *dest = dc_sectorcolormap[colormap[dc_source[flipindex[frac >> FRACBITS]]]];
 }
 
 void R_DrawTranslucentBloodColumn(void)
@@ -846,7 +851,8 @@ void R_DrawDitheredTranslucent50ColumnWithBrightmap(void)
     int                 count = dc_yh - dc_yl + 1;
     byte                *dest = ylookup0[dc_yl] + dc_x;
     fixed_t             frac = dc_texturefrac;
-    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] }, { fullcolormap, fullcolormap } };
+    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] },
+                                            { fullcolormap,   fullcolormap       } };
     byte                dot;
 
     while (--count)
@@ -858,7 +864,7 @@ void R_DrawDitheredTranslucent50ColumnWithBrightmap(void)
     }
 
     dot = dc_source[frac >> FRACBITS];
-    *dest = dc_sectorcolormap[tranmap[(*dest << 8) + colormap[dc_brightmap[dot]][dither(dc_x, dc_yl++, dc_z)][dot]]];
+    *dest = dc_sectorcolormap[tranmap[(*dest << 8) + colormap[dc_brightmap[dot]][dither(dc_x, dc_yl, dc_z)][dot]]];
 }
 
 void R_DrawLowResDitheredTranslucent50ColumnWithBrightmap(void)
@@ -866,7 +872,8 @@ void R_DrawLowResDitheredTranslucent50ColumnWithBrightmap(void)
     int                 count = dc_yh - dc_yl + 1;
     byte                *dest = ylookup0[dc_yl] + dc_x;
     fixed_t             frac = dc_texturefrac;
-    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] }, { fullcolormap, fullcolormap } };
+    const lighttable_t  *colormap[2][2] = { { dc_colormap[0], dc_nextcolormap[0] },
+                                            { fullcolormap,   fullcolormap       } };
     byte                dot;
 
     while (--count)
@@ -878,7 +885,7 @@ void R_DrawLowResDitheredTranslucent50ColumnWithBrightmap(void)
     }
 
     dot = dc_source[frac >> FRACBITS];
-    *dest = dc_sectorcolormap[tranmap[(*dest << 8) + colormap[dc_brightmap[dot]][ditherlow(dc_x, dc_yl++, dc_z)][dot]]];
+    *dest = dc_sectorcolormap[tranmap[(*dest << 8) + colormap[dc_brightmap[dot]][ditherlow(dc_x, dc_yl, dc_z)][dot]]];
 }
 
 void R_DrawLowResDitheredTranslucent50Column(void)
@@ -934,16 +941,17 @@ void R_DrawCorrectedTranslucent50Column(void)
 
 void R_DrawTranslucent50SolidColorColumn(void)
 {
-    int     count = dc_yh - dc_yl + 1;
-    byte    *dest = ylookup0[dc_yl] + dc_x;
+    int         count = dc_yh - dc_yl + 1;
+    byte        *dest = ylookup0[dc_yl] + dc_x;
+    const int   color = (NOTEXTURECOLOR << 8);
 
     while (--count)
     {
-        *dest = dc_sectorcolormap[tranmap[(*dest << 8) + NOTEXTURECOLOR]];
+        *dest = dc_sectorcolormap[tranmap[color + *dest]];
         dest += SCREENWIDTH;
     }
 
-    *dest = dc_sectorcolormap[tranmap[(*dest << 8) + NOTEXTURECOLOR]];
+    *dest = dc_sectorcolormap[tranmap[color + *dest]];
 }
 
 void R_DrawLowResDitheredTranslucent50SolidColorColumn(void)
@@ -1224,7 +1232,7 @@ void R_DrawTranslatedColumn(void)
     *dest = dc_sectorcolormap[colormap[dc_translation[dc_source[frac >> FRACBITS]]]];
 }
 
-void R_DrawDitherLowTranslatedColumn(void)
+void R_DrawLowResDitheredTranslatedColumn(void)
 {
     int                 count = dc_yh - dc_yl + 1;
     byte                *dest = ylookup0[dc_yl] + dc_x;
@@ -1241,7 +1249,7 @@ void R_DrawDitherLowTranslatedColumn(void)
     *dest = dc_sectorcolormap[colormap[ditherlow(dc_x, dc_yl, dc_z)][dc_translation[dc_source[frac >> FRACBITS]]]];
 }
 
-void R_DrawDitherTranslatedColumn(void)
+void R_DrawDitheredTranslatedColumn(void)
 {
     int                 count = dc_yh - dc_yl + 1;
     byte                *dest = ylookup0[dc_yl] + dc_x;
@@ -1415,6 +1423,9 @@ void R_InitBuffer(void)
 
     memset(fuzz1table, 0, MAXSCREENAREA);
     memset(fuzz2table, 0, MAXSCREENAREA);
+
+    for (int i = 0; i < 256; i++)
+        flipindex[i] = (i < 128 ? i : 126 - (i & 127));
 }
 
 void R_FillBezel(void)
