@@ -279,10 +279,7 @@ static void R_InitTables(void)
     // finesine table
     for (int i = 0; i < 5 * FINEANGLES / 4; i++)
         finesine[i] = (fixed_t)(sin((i + 0.5) * M_PI * 2 / FINEANGLES) * FRACUNIT);
-}
 
-static void R_InitPointToAngle(void)
-{
     // slope (tangent) to angle lookup
     for (int i = 0; i <= SLOPERANGE; i++)
         tantoangle[i] = (angle_t)(0xFFFFFFFF * atan((i + 0.5) / SLOPERANGE) / (M_PI * 2));
@@ -427,11 +424,11 @@ void R_ExecuteSetViewSize(void)
     num = FixedMul(FixedDiv(FRACUNIT, fovscale), viewwidth * FRACUNIT / 2);
 
     for (int i = 0; i < viewheight; i++)
-        for (int j = 0; j < LOOKDIRS; j++)
-            yslopes[j][i] = FixedDiv(num, ABS(((i - (viewheight / 2 + (j - LOOKDIRMAX) * 2
+        for (int j = 0; j < PITCHES; j++)
+            yslopes[j][i] = FixedDiv(num, ABS(((i - (viewheight / 2 + (j - PITCHMAX) * 2
                 * setblocks / 10)) << FRACBITS) + FRACUNIT / 2));
 
-    yslope = yslopes[LOOKDIRMAX];
+    yslope = yslopes[PITCHMAX];
 
     // Calculate the light levels to use for each level/scale combination.
     for (int i = 0; i < LIGHTLEVELS; i++)
@@ -599,7 +596,7 @@ void R_InitColumnFunctions(void)
             if (r_detail == r_detail_low)
             {
                 basecolfunc = &R_DrawLowResDitheredColumn;
-                translatedcolfunc = &R_DrawDitherLowTranslatedColumn;
+                translatedcolfunc = &R_DrawLowResDitheredTranslatedColumn;
                 wallcolfunc = &R_DrawLowResDitheredWallColumn;
                 missingcolfunc = &R_DrawLowResDitheredSolidColorColumn;
                 bmapwallcolfunc = &R_DrawLowResDitheredWallColumnWithBrightmap;
@@ -612,7 +609,7 @@ void R_InitColumnFunctions(void)
             else
             {
                 basecolfunc = &R_DrawDitheredColumn;
-                translatedcolfunc = &R_DrawDitherTranslatedColumn;
+                translatedcolfunc = &R_DrawDitheredTranslatedColumn;
                 wallcolfunc = &R_DrawDitheredWallColumn;
                 missingcolfunc = &R_DrawDitheredSolidColorColumn;
                 bmapwallcolfunc = &R_DrawDitheredWallColumnWithBrightmap;
@@ -939,25 +936,22 @@ void R_InitColumnFunctions(void)
 
     if (r_ditheredlighting)
     {
-        if (!norockettrails)
+        if (r_rockettrails_translucency)
         {
-            if (r_rockettrails_translucency)
+            mobjinfo[MT_TRAIL2].colfunc = &R_DrawCorrectedTranslucent50Column;
+            mobjinfo[MT_TRAIL2].altcolfunc = &R_DrawCorrectedTranslucent50Column;
+        }
+        else
+        {
+            if (r_detail == r_detail_low)
             {
-                mobjinfo[MT_TRAIL].colfunc = &R_DrawCorrectedTranslucent50Column;
-                mobjinfo[MT_TRAIL].altcolfunc = &R_DrawCorrectedTranslucent50Column;
+                mobjinfo[MT_TRAIL2].colfunc = &R_DrawCorrectedLowResDitheredColumn;
+                mobjinfo[MT_TRAIL2].altcolfunc = &R_DrawCorrectedLowResDitheredColumn;
             }
             else
             {
-                if (r_detail == r_detail_low)
-                {
-                    mobjinfo[MT_TRAIL].colfunc = &R_DrawCorrectedLowResDitheredColumn;
-                    mobjinfo[MT_TRAIL].altcolfunc = &R_DrawCorrectedLowResDitheredColumn;
-                }
-                else
-                {
-                    mobjinfo[MT_TRAIL].colfunc = &R_DrawCorrectedDitheredColumn;
-                    mobjinfo[MT_TRAIL].altcolfunc = &R_DrawCorrectedDitheredColumn;
-                }
+                mobjinfo[MT_TRAIL2].colfunc = &R_DrawCorrectedDitheredColumn;
+                mobjinfo[MT_TRAIL2].altcolfunc = &R_DrawCorrectedDitheredColumn;
             }
         }
 
@@ -977,18 +971,15 @@ void R_InitColumnFunctions(void)
     }
     else
     {
-        if (!norockettrails)
+        if (r_rockettrails_translucency)
         {
-            if (r_rockettrails_translucency)
-            {
-                mobjinfo[MT_TRAIL].colfunc = &R_DrawCorrectedTranslucent50Column;
-                mobjinfo[MT_TRAIL].altcolfunc = &R_DrawCorrectedTranslucent50Column;
-            }
-            else
-            {
-                mobjinfo[MT_TRAIL].colfunc = &R_DrawCorrectedColumn;
-                mobjinfo[MT_TRAIL].altcolfunc = &R_DrawCorrectedColumn;
-            }
+            mobjinfo[MT_TRAIL2].colfunc = &R_DrawCorrectedTranslucent50Column;
+            mobjinfo[MT_TRAIL2].altcolfunc = &R_DrawCorrectedTranslucent50Column;
+        }
+        else
+        {
+            mobjinfo[MT_TRAIL2].colfunc = &R_DrawCorrectedColumn;
+            mobjinfo[MT_TRAIL2].altcolfunc = &R_DrawCorrectedColumn;
         }
 
         if (!mobjinfo[MT_DOGS].dehacked)
@@ -1015,7 +1006,6 @@ void R_Init(void)
 {
     R_InitClipSegs();
     R_InitData();
-    R_InitPointToAngle();
     R_InitTables();
     R_SetViewSize(r_screensize);
 
@@ -1076,12 +1066,12 @@ static void R_SetupFrame(void)
         viewangle = R_InterpolateAngle(mo->oldangle, mo->angle);
 
         if (canfreelook)
-            pitch = (viewplayer->oldlookdir + (int)((viewplayer->lookdir - viewplayer->oldlookdir)
+            pitch = (viewplayer->oldpitch + (int)((viewplayer->pitch - viewplayer->oldpitch)
                 * FIXED2DOUBLE(fractionaltic))) / MLOOKUNIT;
 
         if (weaponrecoil)
-            pitch = BETWEEN(-LOOKDIRMAX, pitch + viewplayer->oldrecoil
-                + FixedMul(viewplayer->recoil - viewplayer->oldrecoil, fractionaltic), LOOKDIRMAX);
+            pitch = BETWEEN(-PITCHMAX, pitch + viewplayer->oldrecoil
+                + FixedMul(viewplayer->recoil - viewplayer->oldrecoil, fractionaltic), PITCHMAX);
     }
     else
     {
@@ -1091,10 +1081,10 @@ static void R_SetupFrame(void)
         viewangle = mo->angle;
 
         if (canfreelook)
-            pitch = viewplayer->lookdir / MLOOKUNIT;
+            pitch = viewplayer->pitch / MLOOKUNIT;
 
         if (weaponrecoil)
-            pitch = BETWEEN(-LOOKDIRMAX, pitch + viewplayer->recoil, LOOKDIRMAX);
+            pitch = BETWEEN(-PITCHMAX, pitch + viewplayer->recoil, PITCHMAX);
     }
 
     if (shake && !menuactive && !consoleactive && !paused)
@@ -1122,7 +1112,7 @@ static void R_SetupFrame(void)
     extralight = (viewplayer->extralight << 2) + r_extralighting / 3;
 
     centeryfrac = centery << FRACBITS;
-    yslope = yslopes[LOOKDIRMAX + pitch];
+    yslope = yslopes[PITCHMAX + pitch];
 
     viewsin = finesine[viewangle >> ANGLETOFINESHIFT];
     viewcos = finecosine[viewangle >> ANGLETOFINESHIFT];
