@@ -55,25 +55,7 @@ static short    BIGDOOR7;
 static short    FIREBLU1;
 static short    SKY1;
 static short    STEP2;
-
-static bool IsSolidAtSpot(const column_t *column, const int spot)
-{
-    if (!column)
-        return false;
-
-    while (column->topdelta != 0xFF)
-    {
-        if (spot < column->topdelta)
-            return false;
-
-        if (spot <= column->topdelta + column->length)
-            return true;
-
-        column = (const column_t *)((const byte *)column + 3 + column->length + 1);
-    }
-
-    return false;
-}
+static short    TEKWALL1;
 
 // Checks if the lump can be a DOOM patch
 bool R_CheckIfPatch(const int lump)
@@ -221,35 +203,6 @@ static void CreatePatch(int patchnum)
         }
     }
 
-    // copy the patch image down and to the right where there are
-    // holes to eliminate the black halo from bilinear filtering
-    for (int x = 0; x < patch->width; x++)
-    {
-        const rcolumn_t *column = R_GetPatchColumnClamped(patch, x);
-        const rcolumn_t *prevcolumn = R_GetPatchColumnClamped(patch, x - 1);
-
-        // force the first pixel (which is a hole), to use
-        // the color from the next solid spot in the column
-        if (column->pixels[0] == 0xFF)
-            for (int y = 0; y < patch->height; y++)
-                if (column->pixels[y] != 0xFF)
-                {
-                    column->pixels[0] = column->pixels[y];
-                    break;
-                }
-
-        // copy from above or to the left
-        for (int y = 1; y < patch->height; y++)
-            if (!IsSolidAtSpot(oldcolumn, y) && column->pixels[y] == 0xFF)
-            {
-                // this pixel is a hole
-                if (x && prevcolumn->pixels[y - 1] != 0xFF)
-                    column->pixels[y] = prevcolumn->pixels[y];  // copy the color from the left
-                else
-                    column->pixels[y] = column->pixels[y - 1];  // copy the color from above
-            }
-    }
-
     W_ReleaseLumpNum(patchnum);
     free(numpostsincolumn);
 }
@@ -414,8 +367,30 @@ static void CreateTextureCompositePatch(const int id)
                 count = oldcolumn->length;
 
                 // [BH] use incorrect y-origin for certain textures
-                if (id == BIGDOOR7 || id == FIREBLU1 || id == SKY1 || (id == STEP2 && modifiedgame))
+                if (id == BIGDOOR7 || id == FIREBLU1 || id == SKY1 || (id == STEP2 && modifiedgame) || id == TEKWALL1)
                     oy = 0;
+                else if (countsincolumn[tx].patches > 1)
+                {
+                    if (!i)
+                        for (int y = 0; y < count; y++)
+                        {
+                            const int   ty = oy + top + y;
+
+                            if (ty < 0)
+                                continue;
+
+                            if (ty >= compositepatch->height)
+                                break;
+
+                            compositepatch->pixels[tx * compositepatch->height + ty] = oldcolumnpixeldata[y];
+                        }
+
+                    if (oy + top < 0)
+                    {
+                        count += oy;
+                        oy = 0;
+                    }
+                }
 
                 // set up the post's data
                 post->topdelta = top + oy;
@@ -511,6 +486,7 @@ void R_InitPatches(void)
     FIREBLU1 = R_CheckTextureNumForName("FIREBLU1");
     SKY1 = R_CheckTextureNumForName("SKY1");
     STEP2 = R_CheckTextureNumForName("STEP2");
+    TEKWALL1 = R_CheckTextureNumForName("TEKWALL1");
 
     for (int i = 0; i < numspritelumps; i++)
         CreatePatch(firstspritelump + i);
