@@ -77,7 +77,7 @@ static fixed_t      viewx_trans;
 static fixed_t      viewy_trans;
 
 fixed_t             *yslope;
-fixed_t             yslopes[LOOKDIRS][MAXHEIGHT];
+fixed_t             yslopes[PITCHES][MAXHEIGHT];
 
 static fixed_t      cachedheight[MAXHEIGHT];
 
@@ -95,7 +95,7 @@ static void R_MapPlane(const int y, const int x1)
     static fixed_t  cachedanglesindistance[MAXHEIGHT];
     static fixed_t  cachedxstep[MAXHEIGHT];
     static fixed_t  cachedystep[MAXHEIGHT];
-    static fixed_t  cachedangle[MAXHEIGHT];
+    static angle_t  cachedangle[MAXHEIGHT];
     fixed_t         anglecosdistance;
     fixed_t         anglesindistance;
     int             dx;
@@ -493,6 +493,7 @@ void R_DrawPlanes(void)
         updateswirl = !(consoleactive || helpscreen || paused || freeze);
 
     dc_colormap[0] = (fixedcolormap && r_textures ? fixedcolormap : fullcolormap);
+    dc_sectorcolormap = fullcolormap;
 
     for (int i = 0; i < MAXVISPLANES; i++)
         for (visplane_t *pl = visplanes[i]; pl; pl = pl->next)
@@ -500,8 +501,6 @@ void R_DrawPlanes(void)
             {
                 const int   picnum = pl->picnum;
 
-                ds_sectorcolormap = fullcolormap;
-
                 if (picnum == skyflatnum)
                 {
                     dc_iscale = skyiscale;
