@@ -198,9 +198,8 @@ void V_DrawPatch(int x, int y, int screen, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset);
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &screens[screen][((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -307,8 +306,7 @@ void V_DrawShadowPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
 
     desttop = &screens[0][((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -356,8 +354,7 @@ void V_DrawSolidShadowPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
 
     desttop = &screens[0][((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -389,8 +386,7 @@ void V_DrawSpectreShadowPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
 
     desttop = &screens[0][((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -497,6 +493,29 @@ void V_DrawMenuBorderPatch(int x, int y, patch_t *patch)
     }
 }
 
+void V_DrawColorBackPatch(const int x, const int y, const patch_t *patch, const int width,
+    const int height, const int color)
+{
+    byte    *desttop = &screens[0][y * SCREENWIDTH + x];
+
+    for (int col = 0; col < width; col++, desttop++)
+    {
+        byte    *source = (byte *)patch + LONG(patch->columnoffset[col]) + 3;
+        byte    *dest = desttop;
+
+        for (int i = 0; i < height; i++)
+        {
+            if (*source == WHITE)
+                *dest = color;
+            else if (*source != BLACK)
+                *dest = tinttab33[*dest];
+
+            source++;
+            dest += SCREENWIDTH;
+        }
+    }
+}
+
 void V_DrawConsoleTextPatch(const int x, const int y, const patch_t *patch, const int width,
     const int color, const int backgroundcolor, const bool italics, const byte *tinttab)
 {
@@ -617,7 +636,8 @@ void V_DrawConsoleHeaderPatch(int x, int y, patch_t *patch, const int maxwidth,
         {
             if (height > 0)
             {
-                *dest = (*source == WHITE ? color2 : tinttab60[color1 + *dest]);
+                *dest = (*source == WHITE ? (color2 == nearestblack ?
+                    tinttab20[color1 + nearestblack] : color2) : tinttab60[color1 + *dest]);
 
                 if (height == 1)
                     *dest = tinttab60[*dest];
@@ -667,9 +687,9 @@ void V_DrawConsoleBrandingPatch(int x, int y, patch_t *patch, const int color1,
             if (*source && height > 0)
             {
                 if (*source == WHITE)
-                    *dest = color3;
+                    *dest = (color3 == nearestblack ? tinttab20[color1 + nearestblack] : color3);
                 else if (*source == LIGHTGRAY2)
-                    *dest = nearestcolors[(color3 == nearestwhite ? LIGHTGRAY2 : DARKGRAY3)];
+                    *dest = nearestcolors[(color3 == nearestblack ? tinttab25[color1 + nearestblack] : LIGHTGRAY2)];
                 else if (*source == CONSOLEEDGECOLOR2)
                     *dest = tinttab60[color2 + *dest];
                 else
@@ -727,8 +747,8 @@ void V_DrawPatchToTempScreen(int x, int y, patch_t *patch, byte *cr, int screenw
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
-    y -= SHORT(patch->topoffset);
     x -= SHORT(patch->leftoffset);
+    y -= SHORT(patch->topoffset);
 
     desttop = &tempscreen[((y * DY) >> FRACBITS) * screenwidth + ((x * DX) >> FRACBITS)];
 
@@ -882,9 +902,8 @@ void V_DrawMenuPatch(int x, int y, patch_t *patch, bool highlight, int shadowwid
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset);
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &screens[0][((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -935,9 +954,8 @@ void V_DrawBigFontPatch(int x, int y, patch_t *patch, bool highlight, int shadow
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset);
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &tempscreen[((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -967,12 +985,12 @@ void V_DrawBigFontPatch(int x, int y, patch_t *patch, bool highlight, int shadow
 
                 dest += SCREENWIDTH;
 
-                if (height + 2 > 0 && menushadow)
+                if (menushadow && height + 2 > 0 && i <= shadowwidth)
                 {
                     byte    *dot = dest + SCREENWIDTH + 2;
 
-                    if (i <= shadowwidth && *dot != 47 && *dot != 191)
-                        *dot = nearestblack;
+                    if (*dot != 47 && *dot != 191)
+                        *dot = BLUE1;
                 }
 
                 srccol += DYI;
@@ -1168,8 +1186,8 @@ void V_DrawAltHUDPatch(int x, int y, patch_t *patch, int from, int to, const byt
     const int   width = SHORT(patch->width);
     byte        *desttop;
 
-    y -= SHORT(patch->topoffset);
     x -= SHORT(patch->leftoffset);
+    y -= SHORT(patch->topoffset);
 
     desttop = &screens[0][y * SCREENWIDTH + x];
 
@@ -1209,8 +1227,8 @@ void V_DrawTranslucentAltHUDPatch(int x, int y, patch_t *patch, int from, int to
     const int   width = SHORT(patch->width);
     byte        *desttop;
 
-    y -= SHORT(patch->topoffset);
     x -= SHORT(patch->leftoffset);
+    y -= SHORT(patch->topoffset);
 
     desttop = &screens[0][y * SCREENWIDTH + x];
 
@@ -1332,9 +1350,8 @@ void V_DrawTranslucentRedPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset);
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &screens[0][((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -1380,9 +1397,8 @@ void V_DrawFlippedPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset);
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &screens[0][((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -1419,9 +1435,8 @@ void V_DrawFlippedShadowPatch(int x, int y, patch_t *patch)
     const byte  *body = &tinttab40[black];
     const byte  *edge = &tinttab25[black];
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset) / 10;
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &screens[0][(((y + 3) * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -1469,9 +1484,8 @@ void V_DrawFlippedSolidShadowPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset) / 10;
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &screens[0][(((y + 3) * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -1503,9 +1517,8 @@ void V_DrawFlippedSpectreShadowPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset) / 10;
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &screens[0][(((y + 3) * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -1538,9 +1551,8 @@ void V_DrawFlippedTranslucentRedPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset);
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &screens[0][((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -1574,9 +1586,8 @@ void V_DrawFuzzPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset);
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     fuzz1pos = 0;
 
@@ -1616,9 +1627,8 @@ void V_DrawFlippedFuzzPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset);
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     fuzz1pos = 0;
 
@@ -1670,9 +1680,8 @@ void V_DrawNoGreenPatchWithShadow(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset);
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &screens[0][((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
@@ -1718,9 +1727,8 @@ void V_DrawTranslucentNoGreenPatch(int x, int y, patch_t *patch)
     byte        *desttop;
     const int   width = SHORT(patch->width) << FRACBITS;
 
+    x += WIDESCREENDELTA - SHORT(patch->leftoffset);
     y -= SHORT(patch->topoffset);
-    x -= SHORT(patch->leftoffset);
-    x += WIDESCREENDELTA;
 
     desttop = &screens[0][((y * DY) >> FRACBITS) * SCREENWIDTH + ((x * DX) >> FRACBITS)];
 
